@@ -2,7 +2,7 @@ import matplotlib.pyplot as plt
 from mpl_toolkits.axes_grid.anchored_artists import AnchoredText
 from astropy.io.fits import Header
 from astropy.wcs import WCS
-from wcsaxes import WCSAxes
+from astropy.visualization.wcsaxes import WCSAxes
 import pyregion
 
 region_list = [
