@@ -4,7 +4,7 @@ from os.path import join
 from astropy.io.fits import Header
 from .. import open as pyregion_open
 
-rootdir = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'examples')
+rootdir = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data')
 
 
 def demo_header():
@@ -20,4 +20,4 @@ def test_region():
 
     assert isinstance(mask, np.ndarray) and mask.shape == (100, 100)
 
-    # TODO: assert the contect of the mask, too
+    # TODO: assert the content of the mask, too
